@@ -113,7 +113,7 @@ def ohlcv_fill_up_missing_data(dataframe: DataFrame, timeframe: str, pair: str)
     pct_missing = (len_after - len_before) / len_before if len_before > 0 else 0
     if len_before != len_after:
         message = (f"Missing data fillup for {pair}: before: {len_before} - after: {len_after}"
-                   f" - {round(pct_missing * 100, 2)}%")
+                   f" - {pct_missing:.2%}")
         if pct_missing > 0.01:
             logger.info(message)
         else:
