@@ -20,4 +20,4 @@ from freqtrade.exchange.gateio import Gateio
 from freqtrade.exchange.hitbtc import Hitbtc
 from freqtrade.exchange.kraken import Kraken
 from freqtrade.exchange.kucoin import Kucoin
-from freqtrade.exchange.okex import Okex
+from freqtrade.exchange.okx import Okx
