@@ -53,7 +53,7 @@ EXCHANGES = {
         'hasQuoteVolume': True,
         'timeframe': '5m',
     },
-    'okex': {
+    'okx': {
         'pair': 'BTC/USDT',
         'stake_currency': 'USDT',
         'hasQuoteVolume': True,
