@@ -16,7 +16,7 @@ def hyperopt_conf(default_conf):
     hyperconf.update({
         'datadir': Path(default_conf['datadir']),
         'runmode': RunMode.HYPEROPT,
-        'hyperopt': 'HyperoptTestSepFile',
+        'strategy': 'HyperoptableStrategy',
         'hyperopt_loss': 'ShortTradeDurHyperOptLoss',
                          'hyperopt_path': str(Path(__file__).parent / 'hyperopts'),
                          'epochs': 1,
@@ -39,16 +39,25 @@ def hyperopt(hyperopt_conf, mocker):
 def hyperopt_results():
     return pd.DataFrame(
         {
-            'pair': ['ETH/BTC', 'ETH/BTC', 'ETH/BTC'],
-            'profit_ratio': [-0.1, 0.2, 0.3],
-            'profit_abs': [-0.2, 0.4, 0.6],
-            'trade_duration': [10, 30, 10],
-            'sell_reason': [SellType.STOP_LOSS, SellType.ROI, SellType.ROI],
+            'pair': ['ETH/USDT', 'ETH/USDT', 'ETH/USDT', 'ETH/USDT'],
+            'profit_ratio': [-0.1, 0.2, -0.1, 0.3],
+            'profit_abs': [-0.2, 0.4, -0.2, 0.6],
+            'trade_duration': [10, 30, 10, 10],
+            'amount': [0.1, 0.1, 0.1, 0.1],
+            'sell_reason': [SellType.STOP_LOSS, SellType.ROI, SellType.STOP_LOSS, SellType.ROI],
+            'open_date':
+            [
+                datetime(2019, 1, 1, 9, 15, 0),
+                datetime(2019, 1, 2, 8, 55, 0),
+                datetime(2019, 1, 3, 9, 15, 0),
+                datetime(2019, 1, 4, 9, 15, 0),
+            ],
             'close_date':
             [
-                datetime(2019, 1, 1, 9, 26, 3, 478039),
-                datetime(2019, 2, 1, 9, 26, 3, 478039),
-                datetime(2019, 3, 1, 9, 26, 3, 478039)
-            ]
+                datetime(2019, 1, 1, 9, 25, 0),
+                datetime(2019, 1, 2, 9, 25, 0),
+                datetime(2019, 1, 3, 9, 25, 0),
+                datetime(2019, 1, 4, 9, 25, 0),
+            ],
         }
     )
